# Prepare
library(ggplot2)
pdf("./log2FC.pdf")

# Read data
gene <- read.csv("./gene.csv")

# Calculate Fold Change
FC <- rep(0, nrow(gene))
for (i in 1:nrow(gene)) {
  mean_treated <- mean(c(gene$treated1[i], gene$treated2[i], gene$treated3[i])) + 0.01
  mean_control <- mean(c(gene$control1[i], gene$control2[i], gene$control3[i])) + 0.01
  FC[i] <- mean_treated / mean_control
}

# Converted by log2 and add to dataframe
log2FoldChange <- log2(FC)
gene <- data.frame(gene, log2FoldChange)

# Add mean and median to the plot
text_to_plot=data.frame(x=c(1.3,1.3),y=c(13,15),col=c("red","blue"),text=c(paste("Mean=",round(mean(log2FoldChange),5)),paste("Median=",round(median(log2FoldChange),5))))

# Draw boxplot of log2FoldChange
ggplot(gene, aes("",log2FoldChange)) +
  stat_boxplot(geom = "errorbar",width=0.15) + 
  geom_boxplot(size=0.5,fill=c("lemonchiffon")) +
  stat_summary(fun.y="mean",geom="point",shape=23,size=3,fill="white") +
  theme_bw() +
  theme(legend.position="none", 
        axis.text.x=element_text(colour="black",size=14), 
        axis.text.y=element_text(size=14,face="plain"), 
        axis.title.y=element_text(size = 14,face="plain"),
        axis.title.x=element_text(size = 14,face="plain"), 
        plot.title = element_text(size=15,face="bold",hjust = 0.5)) +
  ylab("log2FoldChange") +
  xlab("Gene expression") +
  geom_text(data=text_to_plot,aes(x=text_to_plot$x,y=text_to_plot$y,color=text_to_plot$col,label=text_to_plot$text),size=8)+
  ggtitle("Boxplot for the distribution of log2FoldChange of genes")

dev.off()

